==> mx-repo-manager_24.7.tar.xz: BUILD/translations/mx-repo-manager_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Repo Manager</source>
        <translation>Gerenciador de Repositórios do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Selecione o repositório APT que você pretende utilizar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>Repositórios do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Selecione automaticamente o repositório mais rápido do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Repositórios do Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Selecione automaticamente o repositório mais rápido do Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Fontes individuais</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Restaurar as fontes originais do APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <location filename="../mainwindow.cpp" line="479"/>
        <location filename="../mainwindow.cpp" line="768"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <location filename="../mainwindow.cpp" line="479"/>
        <location filename="../mainwindow.cpp" line="772"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>A sua nova escolha terá efeito na próxima vez que as fontes forem atualizadas (sudo apt update).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Lists</source>
        <translation>Listas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Fontes (as fontes marcadas estão ativadas)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="480"/>
        <location filename="../mainwindow.cpp" line="682"/>
        <location filename="../mainwindow.cpp" line="692"/>
        <location filename="../mainwindow.cpp" line="709"/>
        <location filename="../mainwindow.cpp" line="722"/>
        <location filename="../mainwindow.cpp" line="729"/>
        <location filename="../mainwindow.cpp" line="746"/>
        <location filename="../mainwindow.cpp" line="752"/>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Error</source>
        <translation>Ocorreu um Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="480"/>
        <source>Could not change the repo.</source>
        <translation>Não foi possível alterar o repositório</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>Please wait...</source>
        <translation>Por favor, aguarde ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="562"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="565"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Programa para escolher o repositório APT padrão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Você selecionou o Repositório de Teste (Test Repo) do MX. Não é recomendado deixar este repositório ativado ou atualizar todos os pacotes (programas) atualizáveis a partir das versões disponíveis neste repositório.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="595"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>A opção mais segura é instalar um pacote de cada vez com o Instalador e Desinstalador de Programas do MX.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Selecione o repositório APT e as fontes que você quer utilizar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="682"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>O programa netselect-apt não conseguiu detectar qual é o repositório mais rápido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="692"/>
        <location filename="../mainwindow.cpp" line="709"/>
        <source>Could not detect fastest repo.</source>
        <translation>O programa netselect-apt não conseguiu detectar qual é o repositório mais rápido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>Não foi possível identificar se este aplicativo está sendo executado no antiX Linux ou MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="730"/>
        <source>MX version not detected or out of range: </source>
        <translation>A versão do MX não foi detectada ou está fora do alcance:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="746"/>
        <source>Could not download original APT files.</source>
        <translation>Não foi possível baixar/transferir os arquivos originais do APT.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="752"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Não foi possível descompactar o arquivo baixado/transferido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Enabling AHS</source>
        <translation>Ativando o AHS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Você que utilizar o repositório AHS (Advanced Hardware Stack ou Pilha de Equipamentos Avançado)?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>As fontes originais do APT foram restauradas para o estado inicial de liberação. Os arquivos de origem adicionados pelo usuário em /etc/apt/sources.list.d/ não foram alterados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Ocorreu um erro ao gravar o arquivo %1. Por favor, verifique se você tem espaço livre suficiente no seu dispositivo de armazenamento</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="49"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Ao que parece, você está acessando a sessão com o usuário root. Por favor, saia da sessão atual e entre novamente com o usuário normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Você deve executar este programa com o usuário administrador.</translation>
    </message>
</context>
</TS>

==> mx-repo-manager_24.10.03.tar.xz: BUILD/translations/mx-repo-manager_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>MX Repo Manager</source>
        <translation>Gerenciador de Repositórios do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="642"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Selecione o repositório do APT que você pretende utilizar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>Repositórios do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Selecione automaticamente o repositório mais rápido do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Repositórios do Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Selecione automaticamente o repositório mais rápido do Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Fontes individuais</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Restaurar as fontes originais do APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>About this application</source>
        <translation>Sobre este programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Quit application</source>
        <translation>Sair do programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <location filename="../mainwindow.cpp" line="495"/>
        <location filename="../mainwindow.cpp" line="812"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <location filename="../mainwindow.cpp" line="496"/>
        <location filename="../mainwindow.cpp" line="816"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>A sua nova escolha terá efeito na próxima vez que as fontes forem atualizadas (sudo apt update).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Lists</source>
        <translation>Listas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Fontes (as fontes marcadas estão ativadas)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <location filename="../mainwindow.cpp" line="700"/>
        <location filename="../mainwindow.cpp" line="710"/>
        <location filename="../mainwindow.cpp" line="727"/>
        <location filename="../mainwindow.cpp" line="740"/>
        <location filename="../mainwindow.cpp" line="747"/>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="770"/>
        <location filename="../mainwindow.cpp" line="891"/>
        <source>Error</source>
        <translation>Ocorreu um Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <source>Could not change the repo.</source>
        <translation>Não foi possível alterar o repositório</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Please wait...</source>
        <translation>Por favor, aguarde ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Programa para escolher o repositório APT padrão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="600"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="617"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="618"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Você selecionou o Repositório de Teste (Test Repo) do MX. Não é recomendado deixar este repositório ativado ou atualizar todos os pacotes (programas) atualizáveis a partir das versões disponíveis neste repositório.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>A opção mais segura é instalar um pacote de cada vez com o Instalador e Desinstalador de Programas do MX.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Selecione o repositório APT e as fontes que você quer utilizar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>O programa netselect-apt não conseguiu detectar qual é o repositório mais rápido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="710"/>
        <location filename="../mainwindow.cpp" line="727"/>
        <source>Could not detect fastest repo.</source>
        <translation>O programa netselect-apt não conseguiu detectar qual é o repositório mais rápido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="740"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>Não foi possível identificar se este programa está sendo executado no antiX Linux ou no MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="748"/>
        <source>MX version not detected or out of range: </source>
        <translation>A versão do MX não foi detectada ou está fora do alcance:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Could not download original APT files.</source>
        <translation>Não foi possível baixar/transferir os arquivos originais do APT.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="770"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Não foi possível descompactar o arquivo baixado/transferido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>Enabling AHS</source>
        <translation>Ativando o AHS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Você que utilizar o repositório AHS (Advanced Hardware Stack ou Pilha de Equipamentos Avançado)?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="813"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>As fontes originais do APT foram restauradas para o estado inicial de liberação. Os arquivos de origem adicionados pelo usuário em /etc/apt/sources.list.d/ não foram alterados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="892"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Ocorreu um erro ao gravar o arquivo %1. Por favor, verifique se você tem espaço livre suficiente no seu dispositivo de armazenamento</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="49"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Ao que parece, você está acessando a sessão com o usuário root. Por favor, saia da sessão atual e entre novamente com o usuário normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Você deve executar este programa com o usuário administrador.</translation>
    </message>
</context>
</TS>
